@@ -7,6 +7,8 @@ SEND_EMAIL_ACTION_FROM_EMAIL_MAX_LENGTH = 150
 SEND_EMAIL_ACTION_FROM_NAME_MAX_LENGTH = 50
 SEND_EMAIL_ACTION_CONTENT_MAX_LENGTH = 1500
 SEND_EMAIL_ACTION_RECIPIENT_MAX_LENGTH = 150
+SEND_EMAIL_ACTION_REPLY_TO_EMAIL_MAX_LENGTH = 150
+SEND_EMAIL_ACTION_REPLY_TO_NAME_MAX_LENGTH = 50
 
 EXTERNAL_URL_MAX_LENGTH = 500
 
